@@ -21,26 +21,30 @@
     without including the source code for Qt in the source distribution.
 */                                                                      
 
-#include <qlayout.h>
+#include "kcmweatherservice.h"
+#include "serviceconfigwidget.h"
+
+#include <QtGui/QLayout>
+#include <QtGui/QVBoxLayout>
 
 #include <kaboutdata.h>
 #include <kdebug.h>
 #include <klocale.h>
+#include <kcomponentdata.h>
 
-#include "serviceconfigwidget.h"
-
-#include "kcmweatherservice.h"
 
 extern "C"
 {
   KDE_EXPORT KCModule *create_weatherservice( QWidget *parent, const char * ) {
-    return new KCMWeatherService( parent, "kweather" );
+    return new KCMWeatherService( parent );
   }
 }
 
-KCMWeatherService::KCMWeatherService( QWidget *parent, const char *name )
-  : KCModule( parent, name )
+KCMWeatherService::KCMWeatherService( QWidget *parent)
+  : KCModule(KComponentData("kweather"))
 {
+  Q_UNUSED(parent)
+
   QVBoxLayout *layout = new QVBoxLayout( this );
   mWidget = new ServiceConfigWidget( this );
 
@@ -48,12 +52,12 @@ KCMWeatherService::KCMWeatherService( QWidget *parent, const char *name )
   //connect(mWidget, SIGNAL(changed(bool)), this, SIGNAL(changed(bool)));
 
   layout->addWidget( mWidget );
-  KAboutData *about = new KAboutData( "kcmweatherservice",
-                                      I18N_NOOP( "KWeather Configure Dialog" ),
-                                      0, 0, KAboutData::License_GPL,
-                                      I18N_NOOP( "(c), 2003 Tobias Koenig" ) );
+  KAboutData *about = new KAboutData( "kcmweatherservice", 0,
+                                      ki18n( "KWeather Configure Dialog" ),
+                                      0, KLocalizedString(), KAboutData::License_GPL,
+                                      ki18n( "(c), 2003 Tobias Koenig" ) );
 
-  about->addAuthor( "Tobias Koenig", 0, "tokoe@kde.org" );
+  about->addAuthor( ki18n("Tobias Koenig"), KLocalizedString(), "tokoe@kde.org" );
   setAboutData(about);
 }
 
