@@ -16,11 +16,11 @@
  *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  *  Boston, MA 02110-1301, USA.
  *
- *  $Id: weatherbar.h 709234 2007-09-06 22:08:09Z amth $
+ *  $Id: weatherbar.h 889437 2008-11-26 20:41:28Z schwarzer $
  */
 
-#ifndef KDETOYS_KWEATHER_H
-#define KDETOYS_KWEATHER_H
+#ifndef WEATHERBAR_H
+#define WEATHERBAR_H
 
 #include <konqsidebarplugin.h>
 #include <kparts/part.h>
@@ -64,4 +64,4 @@ private:
     QTimer *timeOut;
 };
 
-#endif // KDETOYS_KWEATHER_H
+#endif // WEATHERBAR_H
